aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/redaction.h
diff options
context:
space:
mode:
authorn-peugnet <n.peugnet@free.fr>2022-10-06 19:27:24 +0200
committern-peugnet <n.peugnet@free.fr>2022-10-06 19:27:24 +0200
commit08632625e1a04257b5c7d4a9db2246ac07436748 (patch)
tree9ddadf219a7e352ddd3549ad1683282c944adfb6 /lib/csapi/redaction.h
parente9c2e2a26d3711e755aa5eb8a8478917c71d612b (diff)
parentd911b207f49e936b3e992200796110f0749ed150 (diff)
downloadlibquotient-08632625e1a04257b5c7d4a9db2246ac07436748.tar.gz
libquotient-08632625e1a04257b5c7d4a9db2246ac07436748.zip
Update upstream source from tag 'upstream/0.7.0'
Update to upstream version '0.7.0' with Debian dir 30dcb77a77433e4a54eab77c0b82ae925dead2d8
Diffstat (limited to 'lib/csapi/redaction.h')
-rw-r--r--lib/csapi/redaction.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/csapi/redaction.h b/lib/csapi/redaction.h
index f0db9f9f..2f85793e 100644
--- a/lib/csapi/redaction.h
+++ b/lib/csapi/redaction.h
@@ -22,7 +22,7 @@ namespace Quotient {
*
* Server administrators may redact events sent by users on their server.
*/
-class RedactEventJob : public BaseJob {
+class QUOTIENT_API RedactEventJob : public BaseJob {
public:
/*! \brief Strips all non-integrity-critical information out of an event.
*
@@ -33,9 +33,9 @@ public:
* The ID of the event to redact
*
* \param txnId
* The transaction ID for this event. Clients should generate a
* unique ID; it will be used by the server to ensure idempotency of
* requests.
*
* \param reason
* The reason for the event being redacted.
@@ -33,9 +33,9 @@ public:
*
* \param txnId
- * The transaction ID for this event. Clients should generate a
- * unique ID; it will be used by the server to ensure idempotency of
- * requests.
+ * The [transaction ID](/client-server-api/#transaction-identifiers) for
+ * this event. Clients should generate a unique ID; it will be used by the
+ * server to ensure idempotency of requests.
*
* \param reason